==> OB-3.1.2.tar.gz: OB-3.1.2/ob/include/OB/Timer.h <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_TIMER_H
#define OB_TIMER_H

//
// The OBTimer class
//
class OBTimer 
{
    friend class OBTimerList;

    //
    // Hide copy-constructor and asignment operator
    //
    OBTimer(const OBTimer&);
    void operator=(const OBTimer&);

protected:

    OBTimer* next_; // Next timer in list
    bool activated_; // Set to true if activated
    timeval timeout_; // The timeout value

    // 
    // Timers are used only as sub classes
    // The bool parameter indicates if timeval is a relativ value
    //
    OBTimer();
    OBTimer(const timeval&, bool = false);
    virtual ~OBTimer();

public:

    //
    // Notification called when timer expires
    //
    virtual void notify() = 0;

    //
    // Activate and stop the timer
    //
    void activate(const timeval&, bool = false);
    void stop();

    bool activated() { return activated_; }
    
    //
    // Get the timeout value
    //
    const timeval& timeout() const { return timeout_; }
};

//
// The OBTimerList class
//
class OBTimerList
{
    //
    // Hide copy-constructor and asignment operator
    //
    OBTimerList(const OBTimerList&);
    void operator=(const OBTimerList&);

protected:

    //
    // The timer list singleton
    //
    static OBTimerList* instance_;
    friend class OBTimerListDestroyer;

    //
    // The head of the timer list
    //
    OBTimer* head_;

    OBTimerList();
    ~OBTimerList();

public:

    //
    // Expire expired timers
    // Returns the number of timers that have expired
    //
    unsigned int expire(const timeval&);

    //
    // Expire one expired timer
    // Returns true if one timer has expired
    //
    bool expireOneTimer(const timeval&);

    //
    // List handling
    //
    bool isEmpty() const { return head_ == 0; }
    OBTimer* first() const { return head_; }
    void add(OBTimer*);
    void remove(OBTimer*);

    //
    // Get the TimerList singleton
    //
    static OBTimerList* instance();

    //
    // Helper functions for handling timeval values
    //
    static int timeCmp(const timeval&, const timeval&);
    static timeval timeSub(const timeval&, const timeval&);
    static timeval timeAdd(const timeval&, const timeval&);
    static timeval timeNow();
};

#endif

==> OB-4.0a2.tar.gz: OB-4.0a2/ob/include/OB/Timer.h <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_TIMER_H
#define OB_TIMER_H

namespace OB
{

//
// The Timer class
//
class Timer 
{
    friend class TimerList;

    //
    // Hide copy-constructor and assignment operator
    //
    Timer(const Timer&);
    void operator=(const Timer&);

protected:

    Timer* next_; // Next timer in list
    bool activated_; // Set to true if activated
    timeval timeout_; // The timeout value

    // 
    // Timers are used only as sub classes
    // The bool parameter indicates if timeval is a relativ value
    //
    Timer();
    Timer(const timeval&, bool = false);
    virtual ~Timer();

public:

    //
    // Notification called when timer expires
    //
    virtual void notify() = 0;

    //
    // Activate and stop the timer
    //
    void activate(const timeval&, bool = false);
    void stop();

    bool activated() { return activated_; }
    
    //
    // Get the timeout value
    //
    const timeval& timeout() const { return timeout_; }
};

//
// The TimerList class
//
class TimerList
{
    //
    // Hide copy-constructor and assignment operator
    //
    TimerList(const TimerList&);
    void operator=(const TimerList&);

protected:

    //
    // The timer list singleton
    //
    static TimerList* instance_;
    friend class TimerListDestroyer;

    //
    // The head of the timer list
    //
    Timer* head_;

    TimerList();
    ~TimerList();

public:

    //
    // Expire expired timers
    // Returns the number of timers that have expired
    //
    unsigned int expire(const timeval&);

    //
    // Expire one expired timer
    // Returns true if one timer has expired
    //
    bool expireOneTimer(const timeval&);

    //
    // List handling
    //
    bool isEmpty() const { return head_ == 0; }
    Timer* first() const { return head_; }
    void add(Timer*);
    void remove(Timer*);

    //
    // Get the TimerList singleton
    //
    static TimerList* instance();

    //
    // Helper functions for handling timeval values
    //
    static int timeCmp(const timeval&, const timeval&);
    static timeval timeSub(const timeval&, const timeval&);
    static timeval timeAdd(const timeval&, const timeval&);
    static timeval timeNow();
};

} // End of namespace OB

#endif
